c $Header: /home/evian/ROOTCVS/ORCA/OPA/SRC_UCL/shine.f,v 1.1.1.1 2001/06/05 11:56:55 valcke Exp $
      subroutine shine(ih,zmue,tfsn,tfsg,ts,hgbq,
     &                 hnbq,zalb,zalcn,zalbp,zalcnp)
c---5----|----5----|----5----|----5----|----5----|----5----|----5----|72--5----|
c
c  Computes albedo of snow-sea ice following SHINE &
c  HENDERSSON-SELLERS [1985].
c
c  albin: Albedo of melting ice in the arctic.
c  albis: Albedo of melting ice in the antarctic (SHINE 
c         & HENDERSSON-SELLERS, 1985).
c  cgren: Correction of the snow or ice albedo to take into account
c         effects of cloudiness (GRENFELL & PEROVICH, 1984)
c
      include 'type.com'
c
      albin = 0.50
      albis = 0.50
      cgren = 0.06
c
c---5----|----5----|----5----|----5----|----5----|----5----|----5----|72--5----|
c  1) Computation of surface albedo.                                   |
c-----------------------------------------------------------------------
c                                                                       
c  zalbp: Albedo for clear sky.
c  zalb:  Albedo for overcast sky.
c                                                                       
c                                                                       
c--1.1 Case of ice or snow.
c--------------------------
c                                                                       
c  albice: Albedo of melting ice.
CEM Idem
      if (ih.eq.1) THEN
CEM Correction for Arctic domain (all values are reduced by 0.1)
        alphd  = 0.70
        alphdi = 0.62
        alphs  = 0.55
CEM  Mise a zero correction nuageuse et reduction de l'albedo glace fondante
        cgren  = 0.00
        albin  = 0.40
C coefficients of linear and cubic functions
        zc1 = 0.372
        zc2 = 0.1467
        zc3 = 1.6
      else
        alphd  = 0.80
        alphdi = 0.72
        alphs  = 0.65
        zc1 = 0.472
        zc2 = 0.2467
        zc3 = 3.6
      endif
CEM Idem
      albice = ih*albin+(1-ih)*albis
c
      if (hnbq.gt.0.0) then                                       
c                                                                       
c  a) Case of ice covered by snow.
c                                                                       
        if (ts.lt.tfsn) then                                      
c                                                                       
c     Freezing snow.
c                                                                       
          if (hnbq.gt.0.05) then                                 
            zalbp = alphd                                        
          else                                                      
            if (hgbq.gt.1.5) then                                
              zalbp = alphdi+(hnbq*(alphd-alphdi)/0.05)          
            else if (hgbq.gt.1.0.and.hgbq.le.1.5) then         
                   al = zc1 +2.0*(alphdi-zc1)*(hgbq-1.0)
            else if (hgbq.gt.0.05.and.hgbq.le.1.0) then        
                   al = zc2 +(0.7049*hgbq)-(0.8608*(hgbq*hgbq))+
     &                 (0.3812*(hgbq*hgbq*hgbq))                     
            else    
                   al = 0.1+zc3*hgbq                                  
            endif                                                   
            if (hgbq.le.1.5) zalbp=al+(hnbq*(alphd-al)/0.05)
          endif                                                     
        else                                                        
c                                                                       
c     Melting snow.
c                                                                       
          if (hnbq.ge.0.1) then                                  
            zalbp = 0.65                                           
            zalbp = alphs                                      
          else                                                      
            zalbp = albice+((alphs-albice)/0.1)*hnbq
          endif                                                     
        endif                                                       
      else                                                          
c                                                                       
c  b) Case of ice free of snow.
c                                                                       
        if (ts.lt.tfsg) then                                      
c                                                                       
c     Freezing ice.
c                                                                       
          if (hgbq.gt.1.5) then                                  
            zalbp = alphdi                                          
          else if (hgbq.gt.1..and.hgbq.le.1.5) then           
	         zalbp = zc1+2.*(alphdi-zc1)*(hgbq-1.)       
          else if (hgbq.gt.0.05.and.hgbq.le.1.) then          
                 zalbp = zc2+                                        
     &                   (0.7049*hgbq)-(0.8608*(hgbq*hgbq))+
     &                   (0.3812*(hgbq*hgbq*hgbq))                  
          else                                                      
            zalbp = 0.1+zc3*hgbq                                
          endif                                                     
        else                                                        
c                                                                       
c     Melting ice.
c                                                                   
          if (hgbq.gt.1.5) then                                  
            zalbp = albice                                           
          else if (hgbq.gt.1..and.hgbq.le.1.5)  then          
                 zalbp = zc1+(2.*(albice-zc1)*(hgbq-1.))     
          else if (hgbq.gt.0.05.and.hgbq.le.1.) then          
                 zalbp = zc2+0.7049*hgbq                          
     &                  -(0.8608*(hgbq*hgbq))
     &                  +(0.3812*(hgbq*hgbq*hgbq)) 
          else                                                      
            zalbp = 0.1+zc3*hgbq
          endif                                                     
        endif                                                       
      endif                                                         
      zalb=zalbp+cgren                                           
c                                                                       
c--1.2. Case of the ocean.
c-------------------------
c                                                                       
      zalcnp=0.05/(1.1*zmue**1.4+0.15)                
c
c  Parameterization of BRIEGLED AND RAMANATHAN (1982)
c
      zalcn=0.06                                                 
c  see KONDRATYEV (1969) AND PAYNE (1972)
      return                                                            
      end                                                               
